# Description
This is a basic python module that contains multiple functions used in different projects.

## Contents

HCGB/sampleParser:

* files.py  
* merge.py  
* samples.py

HCGB/functions:

* aesthetics_functions.py  
* fasta_functions.py  
* main_functions.py	    
* time_functions.py
* blast_functions.py       
* files_functions.py  
* system_call_functions.py

## Copyright & License
MIT License
Copyright (c) 2020-2021 HCGB-IGTP

http://www.germanstrias.org/technology-services/genomica-bioinformatica/

